#!/bin/bash
#
#   USAGE:  buildGeant4.sh <gcc46|gcc47|e2|supcl|f1> <debug|opt|prof> [tar] [source]

make_tarball()
{
    echo ""
    echo "OK - building tarball for ${package} ${pkgver} ${flvr} ${qual}"
    set -x
    cd ${PRODUCTS}
    tarname=${package}-${pkgdotver}-${OS}-${plat}-${qualdir}.tar.bz2
    tar cjf ${tarname} \
       ${package}/${pkgver}.version/${flvr}_${qualver} \
       ${package}/${pkgver}/ups \
       ${package}/${pkgver}/source \
       ${package}/${pkgver}/${flvr}-${qualdir}
    cd ${thisdir}
    set +x
    exit 0
}

make_source_tarball()
{
    set -x
    cd ${PRODUCTS}
    tar cjf ${package}-${pkgdotver}-source.tar.bz2 \
       ${package}/${pkgver}/*.sh \
       ${package}/${pkgver}/ups \
       ${package}/${pkgver}/source
    cd ${thisdir}
    set +x
}

basequal=${1}
extraqual=${2}
maketar=${3}
sourcetar=${4}

package=geant4
pkgver=v4_9_6_p01a
pkgbasever=9.6.1
pkgdotver=`echo ${pkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
thisdir=`pwd`

if [ -z ${PRODUCTS} ]
then
    echo "ERROR: ups is not setup"
    exit 1
fi

if [ "${sourcetar}" = "source" ]
then
  make_source_tarball
fi

if [ -z ${basequal} ]
then
    echo "ERROR: please specify the base qualifier"
    echo "USAGE: buildGeant4.sh <gcc46|gcc47|e2|supcl|f1> <debug|opt|prof> [tar]"
    echo "       in most cases, the base qualifier should be e2"
    exit 1
fi

bqual=`echo ${basequal} | sed 's/:/-/g'`
if [ "${extraqual}" = "debug" ]
then
    qual=${basequal}:debug
    qualdir=${bqual}-debug
    qualver=${extraqual}_${basequal}
elif [ "${extraqual}" = "opt" ]
then
    qual=${basequal}:opt
    qualdir=${bqual}-opt
    qualver=${basequal}_${extraqual}
elif [ "${extraqual}" = "prof" ]
then
    qual=${basequal}:prof
    qualdir=${bqual}-prof
    qualver=${basequal}_${extraqual}
else
    echo "ERROR: please specify debug, opt, or prof"
    echo "USAGE: buildGeant4.sh <gcc46|gcc47|e2|supcl|f1> <debug|opt|prof> [tar]"
    exit 1
fi


source ${PRODUCTS}/setup

OS1=`uname`
if [ ${OS1} = "Darwin" ]
then
    flvr=`ups flavor -2`
    plat=`uname -m`
    OSnum=`uname -r | cut -f1 -d"."`
    macos=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1,2`
    macos1=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1`
    macos2=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 2`
    #OS=${OS1}${OSnum}
    OS=mac${macos1}${macos2}
else
    flvr=`ups flavor`
    plat=`uname -p`
    OSnum=`lsb_release -r | cut -f2 | cut -f1 -d"."`
    OS=${OS1}${OSnum}
    if [ `lsb_release -d | cut  -f3 -d" "` = "SLF" ]
    then
       OS=slf${OSnum}
    fi
   if [ `lsb_release -i | cut -f2` = "ScientificFermi" ]
   then
      OS=slf${OSnum}
   fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "SLC" ]
    then
       OS=slc${OSnum}
    fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "LTS" ]
    then
       OS=slf${OSnum}
    fi
fi

pkgdir=${PRODUCTS}/${package}/${pkgver}/${flvr}-${qualdir}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib64 ]
then
   make_tarball
fi

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi

# declare and then build geant4
echo "Declaring geant4 ${pkgver} for flavor ${flvr}"
if [ ${OS1} = "Darwin" ]
then
   ups declare geant4 ${pkgver} -r geant4/${pkgver} -2 -m geant4.table -q ${qual}
else 
   ups declare geant4 ${pkgver} -r geant4/${pkgver} -4 -m geant4.table -q ${qual}
fi

echo "calling ups build geant4 ${pkgver} -q ${qual}"

ups build geant4 ${pkgver} -q ${qual}

# this should not complain
echo "Finished building geant4 ${pkgver} ${flvr} -q ${qual}"
setup geant4 ${pkgver} -q ${qual}

if [ ! -d ${G4LIB} ]
then
   echo "ERROR: failed to create ${G4LIB}"
   echo "       Something is very wrong"
   exit 1
fi
echo "G4LIB is ${G4LIB}"

# remove build directory from prof and opt distributions
if [ "${extraqual}" = "opt" ]
then
  if [ -d ${pkgdir}/build ]
  then
    rm -rf ${pkgdir}/build
  fi
elif [ "${extraqual}" = "prof" ]
then
  if [ -d ${pkgdir}/build ]
  then
    rm -rf ${pkgdir}/build
  fi
fi


# need to fix paths:
# bin/geant4-config
# lib64/Geant4-9.5.2/Geant4*.cmake
# share/Geant4-9.5.2/geant4make/geant4make*sh

rm -f /tmp/g4fix.sh

echo "#!/bin/bash" > /tmp/g4fix.sh
##echo " set -x " >>  /tmp/g4fix.sh
echo "mv ${GEANT4_FQ_DIR}/bin/geant4-config ${GEANT4_FQ_DIR}/bin/geant4-config.bak" >> /tmp/g4fix.sh
echo "cat ${GEANT4_FQ_DIR}/bin/geant4-config.bak | sed 's%${CLHEP_BASE_DIR}%\${CLHEP_BASE_DIR}%'  | sed 's%${XERCESCROOT}%\${XERCESCROOT}%' > ${GEANT4_FQ_DIR}/bin/geant4-config" >> /tmp/g4fix.sh
echo "chmod +x  ${GEANT4_FQ_DIR}/bin/geant4-config" >> /tmp/g4fix.sh

cmakeConfig=`ls ${GEANT4_FQ_DIR}/lib64/Geant4-${pkgbasever}/Geant4*.cmake`
for file in ${cmakeConfig}
do
  echo "mv ${file} ${file}.bak" >> /tmp/g4fix.sh
  echo "cat ${file}.bak | sed 's%${CLHEP_BASE_DIR}%\$ENV{CLHEP_BASE_DIR}%'  | sed 's%${XERCESCROOT}%\$ENV{XERCESCROOT}%' > ${file}" >> /tmp/g4fix.sh
done

g4make=`ls ${GEANT4_FQ_DIR}/share/Geant4-${pkgbasever}/geant4make/geant4make*sh`
for file in ${g4make}
do
  echo "mv ${file} ${file}.bak" >> /tmp/g4fix.sh
  echo "cat ${file}.bak | sed 's%${CLHEP_BASE_DIR}%\${CLHEP_BASE_DIR}%'  | sed 's%${XERCESCROOT}%\${XERCESCROOT}%' > ${file}" >> /tmp/g4fix.sh
  echo "chmod +x  ${file}" >> /tmp/g4fix.sh
done

chmod +x /tmp/g4fix.sh
/tmp/g4fix.sh

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib64 ]
then
   make_tarball
fi

exit 0
