#!/bin/bash
#

# buildHepPDT.sh <opt|debug|prof> [e2|gcc47|gcc46]
# default is gcc47

extraqual=${1}
basequal=${2}
pkgver=v3_04_01
pkgdotver=`echo ${pkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`

if [ -z ${basequal} ]
then
    basequal=gcc47
fi

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-g -O0"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
else
    echo "ERROR: please specify debug, opt, or prof"
    echo "USAGE: buildHepPDT.sh <opt|debug|prof> [e2|gcc47|gcc46]"
    exit 1
fi

if [ "${basequal}" = "e2" ] ||  [ "${basequal}" = "gcc47" ]
then
   gccdotver=4.7
   gccver=v4_7_1
else
   gccdotver=4.6
   gccver=v4_6_1
fi

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
heppdtdir=${PRODUCTS}/heppdt/${pkgver}/${flvr}-${qualdir}
sourcedir=${PRODUCTS}/heppdt/${pkgver}/source

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ "${basequal}" = "e2" ] 
then
  cxxflg="${cxxflg} -std=c++11 -Wno-deprecated-declarations"
fi

mkdir -p ${heppdtdir}/build
if [ ! -d ${heppdtdir}/build ]
then
   echo "ERROR: failed to create ${heppdtdir}/build"
   exit 1
fi
cd ${heppdtdir}/build

set -x

CXXFLAGS="${cxxflg}" ${sourcedir}/HepPDT-${pkgdotver}/configure --prefix=${heppdtdir} 
make 
make check
make install 

set +x

if [ ! -d ${heppdtdir}/lib ]
then
   echo "ERROR: failed to create ${heppdtdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
   echo "Finished building heppdt for flavor ${flvr}"
   echo "Declaring heppdt ${pkgver} for this flavor"
if [ ${OS} = "Darwin" ]
then
   ups declare heppdt ${pkgver} -r heppdt/${pkgver} -2 -m heppdt.table -q ${fullqual}
else 
   ups declare heppdt ${pkgver} -r heppdt/${pkgver} -4 -m heppdt.table -q ${fullqual}
fi
setup heppdt ${pkgver} -q ${fullqual}
echo "heppdt is installed at ${HEPPDT_FQ_DIR}"

exit 0
