#!/bin/bash
#
# buildRoot.sh <gcc47|mu2e:gcc47|nu:gcc47|e2|mu2e:e2|nu:e2> <opt|debug|prof> [tar] [source]

make_tarball()
{
    echo ""
    set -x
    cd ${PRODUCTS}
    tarname=${package}-${pkgdotver}-${OS}-${plat}-${qualdir}.tar.bz2
    tar cjf ${tarname} \
       ${package}/${pkgver}.version/${flvr}_${qualver} \
       ${package}/${pkgver}/ups \
       ${package}/${pkgver}/${flvr}-${qualdir}
    cd ${thisdir}
    set +x
    exit 0
}

make_source_tarball()
{
    set -x
    cd ${PRODUCTS}
    tar cjf ${package}-${pkgdotver}-source.tar.bz2 \
       ${package}/${pkgver}/*.sh \
       ${package}/${pkgver}/MyRules* \
       ${package}/${pkgver}/ups \
       ${package}/${pkgver}/source
    cd ${thisdir}
    set +x
}

basequal=${1}
extraqual=${2}
maketar=${3}
sourcetar=${4}

# check to see if qualifier is set
if [ -z ${basequal} ]
then
   echo "ERROR: please specify the qualifiers"
   echo "USAGE: buildRoot.sh <gcc47|mu2e:gcc47|nu:gcc47|e2|mu2e:e2|nu:e2> <debug|opt|prof> [tar]"
   exit 1
fi

package=root
pkgver=v5_34_05
pkgdotver=5.34.05
pkgtarfile=root_v${pkgdotver}.source.tar.gz
patchfile=fermi_root_5_34.patch
gccdotver=4.7
gccver=v4_7_1
thisdir=`pwd`

if [ "${sourcetar}" = "source" ]
then
  make_source_tarball
fi

if [ "${basequal}" = "gcc47" ] 
then
    shortqual=gcc
elif [ "${basequal}" = "nu:gcc47" ] 
then
    shortqual=nu
elif [ "${basequal}" = "mu2e:gcc47" ] 
then
    shortqual=mu2e
elif [ "${basequal}" = "e2" ] 
then
    shortqual=e
    cqual=e2
    c11="--enable-c++11"
elif [ "${basequal}" = "nu:e2" ] 
then
    shortqual=nu
    cqual=e2
    c11="--enable-c++11"
elif [ "${basequal}" = "mu2e:e2" ] 
then
    shortqual=mu2e
    cqual=e2
    c11="--enable-c++11"
else
   echo "ERROR: unrecognized qualifier"
   echo "USAGE: buildRoot.sh <gcc47|mu2e:gcc47|nu:gcc47|e2|mu2e:e2|nu:e2> <debug|opt|prof>"
   exit 1
fi

# use ROOTSYS/MyRules.mk
if [ "${extraqual}" = "opt" ]
then
    rules=MyRules_opt.mk
elif [ "${extraqual}" = "debug" ]
then
    extracommand="--build=debug"
    rules=MyRules_debug.mk
elif [ "${extraqual}" = "prof" ]
then
    rules=MyRules_prof.mk
else
    # default CXXFLAGS are -g -O2
   echo "ERROR: please specify debug, opt, or prof"
   echo "USAGE: buildRoot.sh <gcc47|mu2e:gcc47|nu:gcc47|e2|mu2e:e2|nu:e2> <debug|opt|prof>"
   exit 1
fi
fullqual=${basequal}:${extraqual}
xqual=`echo ${basequal} | sed -e s%:%-%g`
qualdir=${xqual}-${extraqual}
qlist=`echo ${fullqual} | sed -e 's/:/ /g' | tr " " "\n"| sort |tr "\n" " "`
qualver=`echo ${qlist} | tr " " "_"`

echo "compiling for ${fullqual}"

source ${PRODUCTS}/setup
OS1=`uname`
if [ ${OS1} = "Darwin" ]
then
    flvr=`ups flavor -2`
    plat=`uname -m`
    OSnum=`uname -r | cut -f1 -d"."`
    macos=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1,2`
    macos1=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1`
    macos2=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 2`
    #OS=${OS1}${OSnum}
    OS=mac${macos1}${macos2}
else
    flvr=`ups flavor`
    plat=`uname -p`
    OSnum=`lsb_release -r | cut -f2 | cut -f1 -d"."`
    OS=${OS1}${OSnum}
    if [ `lsb_release -d | cut  -f3 -d" "` = "SLF" ]
    then
       OS=slf${OSnum}
    fi
   if [ `lsb_release -i | cut -f2` = "ScientificFermi" ]
   then
      OS=slf${OSnum}
   fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "SLC" ]
    then
       OS=slc${OSnum}
    fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "LTS" ]
    then
       OS=slf${OSnum}
    fi
fi

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

pkgdir=${PRODUCTS}/${package}/${pkgver}/${flvr}-${qualdir}
sourcedir=${PRODUCTS}/${package}/${pkgver}/source

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   make_tarball
fi

# declare now so we can setup
mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi

echo "Declaring ${package} ${pkgver} ${flvr} -q ${fullqual}"
if [ ${OS1} = "Darwin" ]
then
   ups declare ${package} ${pkgver} -r ${package}/${pkgver} -2 -m ${package}.table -q ${fullqual}
else 
   ups declare ${package} ${pkgver} -r ${package}/${pkgver} -4 -m ${package}.table -q ${fullqual}
fi

# setup root
setup ${package} ${pkgver} -q ${fullqual}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ -z ${FFTW_INC} ]
then
   echo "ERROR: failed to setup fftw"
   exit 1
else
   echo "FFTW_INC: ${FFTW_INC}"
fi

if [ -z ${LIBXML2_INC} ]
then
   echo "ERROR: failed to setup libxml"
   exit 1
else
   echo "LIBXML2_INC: ${LIBXML2_INC}"
fi

if [ "${shortqual}" = "nu" ] 
then
    if [ -z ${POSTGRESQL_VERSION} ]
    then
       echo "ERROR: failed to setup postgresql"
       exit 1
    else
       echo "postgresql version: ${POSTGRESQL_VERSION}"
    fi

    if [ -z ${MYSQL_CLIENT_VERSION} ]
    then
       echo "ERROR: failed to setup mysql_client"
       exit 1
    else
       echo "mysql_client version: ${MYSQL_CLIENT_VERSION}"
    fi
fi

if [ -z ${PYTHONHOME} ]
then
   echo "ERROR: PYTHONHOME is undefined"
   echo "       something is very wrong"
   exit 1
fi

cd ${pkgdir}
tar xzf ${sourcedir}/${pkgtarfile}

# get the extra rules 
if [ -n ${rules} ]
then
   cp ${ROOT_DIR}/${rules} ${pkgdir}/${package}/MyRules.mk
fi
if [ "${cqual}" = "e2" ] 
then
  echo "CXXFLAGS += -std=c++11 -Wno-deprecated-declarations" >> ${pkgdir}/root/MyRules.mk
  echo "NOOPT += -std=c++11 -Wno-deprecated-declarations" >> ${pkgdir}/root/MyRules.mk
fi

set -x

cd ${pkgdir}/root

# apply Fermi patches
patch -b -p0 < ${sourcedir}/${patchfile}

if [ "${shortqual}" = "nu" ]
then
./configure ${extracommand} \
--enable-gdml ${c11} \
--enable-roofit \
--with-fftw3-incdir=${FFTW_INC} \
--with-fftw3-libdir=${FFTW_FQ_DIR}/lib/ \
--disable-xrootd \
--enable-minuit2 \
--disable-xft \
--with-xml-incdir=${LIBXML2_INC} \
--with-xml-libdir=${LIBXML2_FQ_DIR}/lib \
--with-pythia6-libdir=${PYLIB} \
--with-pgsql-incdir=${POSTGRESQL_FQ_DIR}/include \
--with-pgsql-libdir=${POSTGRESQL_FQ_DIR}/lib \
--with-mysql-incdir=${MYSQL_CLIENT_FQ_DIR}/include \
--with-mysql-libdir=${MYSQL_CLIENT_FQ_DIR}/lib
elif [ "${shortqual}" = "mu2e" ]
then
./configure ${extracommand} \
--enable-gdml ${c11} \
--enable-roofit \
--with-fftw3-incdir=${FFTW_INC} \
--with-fftw3-libdir=${FFTW_FQ_DIR}/lib/ \
--disable-mysql \
--disable-xrootd \
--enable-minuit2 \
--disable-xft \
--with-xml-incdir=${LIBXML2_INC} \
--with-xml-libdir=${LIBXML2_FQ_DIR}/lib
else
./configure ${extracommand} \
--enable-gdml ${c11} \
--with-fftw3-incdir=${FFTW_INC} \
--with-fftw3-libdir=${FFTW_FQ_DIR}/lib/ \
--disable-mysql \
--disable-xrootd \
--enable-minuit2 \
--disable-xft \
--with-xml-incdir=${LIBXML2_INC} \
--with-xml-libdir=${LIBXML2_FQ_DIR}/lib
fi

make -j3
# now install in ROOTSYS
make install 

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building ${package} ${pkgver} ${flvr} -q ${fullqual}"
setup ${package} ${pkgver} -q ${fullqual}
echo "${package} is installed at ${ROOTSYS}"

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   make_tarball
fi

exit 0
