#!/bin/sh
#
# Note that scons is an executable, 
# so we do not normally build debug or opt versions.

# buildScons.sh [gcc47|gcc46]
# default is gcc47

basequal=${1}
pkgver=v2_1_0
pkgdotver=2.1.0

if [ -z ${basequal} ]
then
    basequal=gcc47
fi

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

if [ "${basequal}" = "gcc47" ]
then
   gccdotver=4.7
   gccver=v4_7_1
   pyver=v2_7_3
else
   gccdotver=4.6
   gccver=v4_6_1
   pyver=v2_7_2
fi

sconsdir=${PRODUCTS}/scons/${pkgver}/${flvr}-${basequal}
sourcedir=${PRODUCTS}/scons/${pkgver}/source

# need python
setup python ${pyver} -q ${basequal}

# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ -z ${PYTHONHOME} ]
then
   echo "ERROR: PYTHONHOME is undefined"
   echo "       please setup python"
   exit 1
fi

mkdir -p ${sconsdir}
if [ ! -d ${sconsdir} ]
then
   echo "ERROR: failed to create ${sconsdir}"
   exit 1
fi

set -x

cd ${sconsdir}
tar -xzf ${sourcedir}/scons-${pkgdotver}.tar.gz
cd ${sconsdir}/scons-${pkgdotver}

python setup.py install --prefix=${sconsdir}

set +x

if [ ! -d ${sconsdir}/bin ]
then
   echo "ERROR: failed to create ${sconsdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi

if [ ! -d ${sconsdir}/lib ]
then
   echo "ERROR: failed to create ${sconsdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building scons for flavor ${flvr}"
echo "Declaring scons ${pkgver} for flavor ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare scons ${pkgver} -r scons/${pkgver} -2 -m scons.table -q ${basequal}
else 
   ups declare scons ${pkgver} -r scons/${pkgver} -4 -m scons.table -q ${basequal}
fi
setup scons ${pkgver} -q ${basequal}
which scons

exit 0
