#!/bin/bash
#

# buildXerces.sh <opt|debug|prof> [e2|gcc47|gcc46]
# default is gcc47

extraqual=${1}
basequal=${2}

pkgver=v3_1_1
pkgdotver=3.1.1

if [ -z ${basequal} ]
then
    basequal=gcc47
fi

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-g -O0"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
else
    echo "ERROR: please specify debug, opt, or prof"
    echo "USAGE: buildXerces.sh <opt|debug|prof> [e2|gcc47|gcc46]"
    exit 1
fi
cflg=${cxxflg}

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
XERCESCROOT=${PRODUCTS}/xerces_c/${pkgver}/${flvr}-${qualdir}
xersource=${PRODUCTS}/xerces_c/${pkgver}/source

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

if [ "${basequal}" = "e2" ] ||  [ "${basequal}" = "gcc47" ]
then
   gccdotver=4.7
   gccver=v4_7_1
else
   gccdotver=4.6
   gccver=v4_6_1
fi

# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ "${basequal}" = "e2" ] 
then
  cxxflg="${cxxflg} -std=c++11 -Wno-deprecated-declarations"
fi

mkdir -p ${XERCESCROOT}/build
if [ ! -d ${XERCESCROOT}/build ]
then
   echo "ERROR: failed to create ${XERCESCROOT}/build"
   exit 1
fi
cd ${XERCESCROOT}/build

set -x

CXXFLAGS="${cxxflg}" CFLAGS="${cflg}" ${xersource}/xerces-c-${pkgdotver}/configure --prefix=${XERCESCROOT} 
make 
make install 

set +x

if [ ! -d ${XERCESCROOT}/lib ]
then
   echo "ERROR: failed to create ${XERCESCROOT}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building xerces_c for flavor ${flvr}"
echo "Declaring xerces_c ${pkgver} for ${flvr} and ${fullqual}"
if [ ${OS} = "Darwin" ]
then
   ups declare xerces_c ${pkgver} -r xerces_c/${pkgver} -2 -m xerces_c.table -q ${fullqual}
else 
   ups declare xerces_c ${pkgver} -r xerces_c/${pkgver} -4 -m xerces_c.table -q ${fullqual}
fi
setup xerces_c ${pkgver} -q ${fullqual}
echo "xerces_c is installed at ${XERCESCROOT}"

exit 0
